.. _docdb_admin_status:

======
Status
======

The DocDB compilers can be monitored from the **Status** tab on the Peek Admin UI.

----

The labels have the following meaning :

:Is Running: Is the compiler running

:Queue Size: The number of chunks that the worker is currently compiling.

:Total Processed: The total number of chunks sent to the worker for compile,
    since the last Peek Server restart.

----

.. image:: status.png
